module Debate.Arguments.Nutrition.HealthyPlantFoods exposing (..)

import Debate.Types exposing (..)


argumentHealthyPlantFoods : Argument
argumentHealthyPlantFoods =
    { argumentTitle = "Argument for Overwhelmingly Healthy Plant Foods"
    , propositionTitle = "Whole plant foods are overwhelmingly healthy."
    , propositionSummary = "Summary"
    , proofLink  = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qf)|=(Pf)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) is overwhelmingly healthy"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates"
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "w"
          , definiens = "whole plant foods"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, food (x) is overwhelmingly healthy if, and only if, food (x) consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "(∀x(Px↔Qx))"
                  }
                , { premise = "Whole plant foods consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "(Qw)"
                  }
                ]
          , conclusion = "Therefore, whole plant foods are overwhelmingly healthy."
          , conclusionNotation = "(∴Pw)"
          }
        ]
    }