module Debate.Arguments.Nutrition.PolyphenolReductio exposing (..)

import Debate.Types exposing (..)


argumentPolyphenolReductio : Argument
argumentPolyphenolReductio =
    { argumentTitle = "Anti-Polyphenol Reductio"
    , propositionTitle = "Anti-polyphenol, ancestral diet advocates are committed to favouring GMOs."
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x~6y(Hx~1Cxy~5Vxy)),(Hp),(Cpg),(Vpg~5Mpg),(Vpg),(Mpg~5Gp)|=(Gp)"
    , definitionTable =
        [ { definiendum = "H(x)"
          , definiens = "(x) is harmful"
          }
        , { definiendum = "C(x,y)"
          , definiens = "(x) is contained in (y)"
          }
        , { definiendum = "V(x,y)"
          , definiens = "(x) renders (y) harmful"
          }
        , { definiendum = "M(p,g)"
          , definiens = "genetic modification that removes (p) from grass renders (g) less harmful"
          }
        , { definiendum = "G(p)"
          , definiens = "health-conscious, anti-polyphenol, ancestral diet advocates are committed to favouring GMOs"
          }
        , { definiendum = "x"
          , definiens = "plant defense chemicals"
          }
        , { definiendum = "y"
          , definiens = "a food"
          }
        , { definiendum = "p"
          , definiens = "polyphenols"
          }
        , { definiendum = "g"
          , definiens = "grass-fed beef"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If plant defense chemicals (x) are harmful and plant defense chemicals (x) are contained in a food (y), then plant defense chemicals (x) render the food (y) harmful."
                  , notation = "(∀x∀y(Hx∧Cxy→Vxy))"
                  }
                , { premise = "Polyphenols from grass are harmful."
                  , notation = "(Hp)"
                  }
                , { premise = "Polyphenols from grass are contained in grass-fed beef."
                  , notation = "(Cpg)"
                  }
                , { premise = "If polyphenols from grass render grass-fed beef harmful, then genetic modification that removes polyphenols from grass renders grass-fed beef less harmful."
                  , notation = "(Vpg→Mpg)"
                  }
                , { premise = "Polyphenols from grass render grass-fed beef harmful."
                  , notation = "(Vpg)"
                  }
                , { premise = "If genetic modification that removes polyphenols from grass renders grass-fed beef less harmful, then health-conscious, anti-polyphenol, ancestral diet advocates are committed to favouring GMOs."
                  , notation = "(Mpg→Gp)"
                  }
                ]
          , conclusion = "Therefore, health-conscious, anti-polyphenol, ancestral diet advocates are committed to favouring GMOs."
          , conclusionNotation = "(∴Gp)"
          }
        ]
    }
