module Debate.Arguments.Philosophy.AntiRewilding exposing (..)

import Debate.Types exposing (..)


argumentAntiRewilding : Argument
argumentAntiRewilding =
    { argumentTitle = "Argument Against Rewilding"
    , propositionTitle = "Rewilding sentient animals is immoral."
    , propositionSummary = "Summary"
    , proofLink  = "https://www.umsu.de/trees/#(~6x(Wx~5~3Nx)),(Wa),(~3Na~5~3F),(~3F~5Ra)|=(Ra)"
    , definitionTable =
        [ { definiendum = "W(x)"
          , definiens = "(x) has negative rights"
          }
        , { definiendum = "N(x)"
          , definiens = "we should defend (x) from rights violations to any lesser degree than we would tolerate for humans"
          }
        , { definiendum = "F"
          , definiens = "it is permissible to subject animals to conditions that are likely to involve predation, starvation, or death due to environmental exposure to any greater degree than we would tolerate for humans"
          }
        , { definiendum = "R(a)"
          , definiens = "rewilding sentient animals is immoral"
          }
        , { definiendum = "x"
          , definiens = "a being"
          }
        , { definiendum = "sentient animals"
          , definiens = "a"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a being (x) has negative rights, then we should not defend a being (x) from rights violations to any lesser degree than we would tolerate for humans."
                  , notation = "(∀x(Wx→¬Nx))"
                  }
                , { premise = "Sentient animals have negative rights."
                  , notation = "(Wa)"
                  }
                , { premise = "If we should not defend sentient animals from rights violations to any lesser degree than we would tolerate for humans, then it is not permissible to subject sentient animals to conditions that are likely to involve predation, starvation, or death due to environmental exposure to any greater degree than we would tolerate for humans."
                  , notation = "(¬Na→¬F)"
                  }
                , { premise = "If it is not permissible to subject sentient animals to conditions that are likely to involve predation, starvation, or death due to environmental exposure to any greater degree than we would tolerate for humans, then rewilding sentient animals is immoral."
                  , notation = "(¬F→Ra)"
                  }
                ]
          , conclusion = "Therefore, rewilding sentient animals is immoral."
          , conclusionNotation = "(∴Ra)"
          }
        ]
    }