module Debate.Arguments.Philosophy.OddOrderPredators exposing (..)

import Debate.Types exposing (..)


argumentOddOrderPredators : Argument
argumentOddOrderPredators =
    { argumentTitle = "Argument for Culling Odd Order Predators"
    , propositionTitle = "It is permissible to prevent predation with lethal force to the same degree we would tolerate for humans."
    , propositionSummary = "Summary"
    , proofLink  = "https://www.umsu.de/trees/#(~6x(Wx~5~3Nx)),(Wa),(~3Na~5F)%7C=(F)"
    , definitionTable =
        [ { definiendum = "W(x)"
          , definiens = "(x) has negative rights"
          }
        , { definiendum = "N(x)"
          , definiens = "we should defend (x) from rights violations to any lesser degree than we would tolerate for humans"
          }
        , { definiendum = "F(x)"
          , definiens = "it is permissible to prevent predation with lethal force to the same degree we would tolerate for humans"
          }
        , { definiendum = "a"
          , definiens = "animal"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if something has negative rights, then we should not defend it from rights violations to any lesser degree than we would tolerate for humans."
                  , notation = "(∀x(Wx→¬Nx))"
                  }
                , { premise = "Animals have negative rights."
                  , notation = "(Wa)"
                  }
                , { premise = "If we should not defend animals from rights violations to any lesser degree than we would tolerate for humans, then it is permissible to prevent predation with lethal force to the same degree we would tolerate for humans."
                  , notation = "(¬Na→F)"
                  }
                ]
          , conclusion = "Therefore, it is permissible to prevent predation with lethal force to the same degree we would tolerate for humans."
          , conclusionNotation = "(∴F)"
          }
        ]
    }