module Debate.Arguments.Philosophy.Ostroveganism exposing (..)

import Debate.Types exposing (..)


argumentOstroveganism : Argument
argumentOstroveganism =
    { argumentTitle = "Argument for Vegan Bivalves"
    , propositionTitle = "Bivalves are not likely to be sentient."
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x(Bx~4Px~1Qx~1(Rx~2Sx))),(Pc~1~3Qc~1Rc~1~3Sc),(~3Bc~5~6x(~3Nx))%7C=(~3Nb)"
    , definitionTable =
        [ { definiendum = "B(x)"
          , definiens = "(x) counts as a brain"
          }
        , { definiendum = "P(x)"
          , definiens = "(x) is a complex network of interconnected neurons"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) integrates neuronal pathways from multiple sensory organs"
          }
        , { definiendum = "R(x)"
          , definiens = "(x) presents with distinct functional regions"
          }
        , { definiendum = "S(x)"
          , definiens = "(x) presents with nuclei with white matter tracts that facilitate inter-regional communication"
          }
        , { definiendum = "N(x)"
          , definiens = "the corresponding (y) is likely to be sentient"
          }
        , { definiendum = "x"
          , definiens = "an object"
          }
        , { definiendum = "y"
          , definiens = "brainless biological system into which cerebral ganglia are integrated"
          }
        , { definiendum = "c"
          , definiens = "cerebral ganglia"
          }
             , { definiendum = "b"
          , definiens = "bivalves"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "Something counts as a brain if, and only if, something is a complex network of interconnected neurons, integrates neuronal pathways from multiple sensory organs, and presents with distinct functional regions or nuclei with white matter tracts that facilitate inter-regional communication."
                  , notation = "(∀x(Bx↔Px∧Qx∧(Rx∨Sx)))"
                  }
                , { premise = "Cerebral ganglia meet criteria one and three, but not criteria two and four."
                  , notation = "(Pc∧¬Qc∧Rc∧¬Sc)"
                  }
                , { premise = "If cerebral ganglia do not count as brains, then the corresponding brainless biological system into which the cerebral ganglia are integrated is not likely to be sentient."
                  , notation = "(¬Bc→∀x(¬Nx))"
                  }
                ]
          , conclusion = "Therefore, bivalves are not likely to be sentient."
          , conclusionNotation = "(∴¬Nb)"
          }
        ]
    }
