module Debate.Arguments.Philosophy.AnimalRights exposing (..)

import Debate.Types exposing (..)


argumentAnimalRights : Argument
argumentAnimalRights =
    { argumentTitle = "Argument for Animal Rights"
    , propositionTitle = "We should not exploit animals to any greater degree than we would tolerate for humans."
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x(Wx~5Nx)),(~3Wa~5~7t(Ata~5(Ath~5~3Wh))),(~3~7t(Ata~5(Ath~5~3Wh))),(Wa)%7C=(Na)"
    , definitionTable =
        [ { definiendum = "W(x)"
          , definiens = "(x) has moral worth"
          }
        , { definiendum = "N(x)"
          , definiens = "we should exploit (x) to any greater degree than we would tolerate for humans"
          }
           , { definiendum = "∃t(At(x)"
          , definiens = "there exists a (t) that is absent in (x)"
          }
        , { definiendum = "x"
          , definiens = "a being"
          }
        , { definiendum = "t"
          , definiens = "trait"
          }
        , { definiendum = "a"
          , definiens = "animal"
          }
        , { definiendum = "h"
          , definiens = "human"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a being has moral worth, then we should not exploit it to any greater degree than we would tolerate for humans."
                  , notation = "(∀x(Wx→Nx))"
                  }
                , { premise = "If animals don’t have moral worth, then there exists a trait that is absent in animals such that if it were absent in humans, humans wouldn’t have moral worth."
                  , notation = "(¬Wa→∃t(Ata→(Ath→¬Wh)))"
                  }
                , { premise = "There doesn’t exist a trait that is absent in animals such that if it were absent in humans, humans wouldn’t have moral worth"
                  , notation = "(¬∃t(Ata→(Ath→¬Wh)))"
                  }
                ]
          , conclusion = "Therefore, we should not exploit animals to any greater degree than we would tolerate for humans."
          , conclusionNotation = "(∴Na)"
          }
        ]
    }
